/**
 * @description  tree的处理
 * @param {Array} data
 * @returns
 */

export function buildTree(data) {
  const tree = {};
  data.forEach(item => {
    const code = item.type.code;
    const node = {
      icon: item.icon,
      id: item.id,
      name: item.name,
    };

    if (!tree[code]) {
      tree[code] = {
        code: code,
        description: item.type.description,
        children: [node],
      };
    } else {
      tree[code].children.push(node);
    }
  });

  return Object.values(tree);
}

/**
 * @description 电话号码加密   18285564342 转化为 182****4342
 * @param {String} phone
 * @returns
 */

export function phoneEncryption(phone) {
  return phone.replace(/^(\d{3})\d{4}(\d+)/, '$1****$2');
}

/**
 * @description 身份证号码加密
 * @param {*} idCard
 * @returns
 */

export function idCardEncryption(idCard) {
  if (!idCard) return '';
  let reg = /^(.{6})(?:\d+)(.{4})$/;
  // 身份证号脱敏，将中间8位替换为“*”
  let result = idCard.replace(reg, '$1******$2');
  return result;
}
